@@ -71,7 +71,7 @@ static inline int wcwidth(wchar_t c)
 #endif
 
 
-int _wtoi(const wchar_t *iWStr)
+int wtoi(const wchar_t *iWStr)
 {
     return wcstol(iWStr, NULL, 10);
 }
@@ -354,7 +354,7 @@ unsigned int readFromUTF8(wchar_t *oString, unsigned int iWideSize,
                           const string &iContext)
 {
 #ifdef WIN32
-    if (iBuffer == NULL || *iBuffer == '\0')
+    if (iBufSize == 0 || iBuffer == NULL || *iBuffer == '\0')
     {
         return 0;
     }
