@@ -52,6 +52,7 @@
 #include "player_widget.h"
 #include "history_widget.h"
 #include "dic_tools_widget.h"
+#include "dic_wizard.h"
 #include "aux_window.h"
 #include "qtcommon.h"
 
@@ -169,6 +170,7 @@ MainWindow::MainWindow(QWidget *iParent)
         {
             displayErrorMsg(_q("Cannot load dictionary '%1' indicated in the "
                                "preferences.\nReason: %2").arg(dicPath).arg(e.what()));
+            return;
         }
     }
     emit dicChanged(m_dic);
@@ -282,7 +284,7 @@ void MainWindow::updateForGame(const PublicGame *iGame)
 void MainWindow::updateStatusBar(const Dictionary *iDic)
 {
     if (iDic == NULL)
-        m_dicNameLabel->setText("No dictionary");
+        m_dicNameLabel->setText(_q("No dictionary"));
     else {
         QString dicName = qfw(m_dic->getHeader().getName());
         m_dicNameLabel->setText(_q("Dictionary: %1").arg(dicName));
@@ -351,6 +353,45 @@ void MainWindow::readSettings()
 }
 
 
+void MainWindow::changeDictionary(QString iFileName)
+{
+    if (!iFileName.isEmpty())
+    {
+        if (m_game)
+        {
+            QString msg = _q("Loading a dictionary will stop the current game.");
+            QMessageBox confirmationBox(QMessageBox::Question, _q("Eliot"), msg,
+                                        QMessageBox::Yes | QMessageBox::No, this);
+            confirmationBox.setInformativeText(_q("Do you want to continue?"));
+            confirmationBox.setDefaultButton(QMessageBox::Yes);
+            confirmationBox.setEscapeButton(QMessageBox::No);
+            int res = confirmationBox.exec();
+            if (res == QMessageBox::No)
+                return;
+        }
+
+        destroyCurrentGame();
+
+        try
+        {
+            Dictionary *dic = new Dictionary(qtl(iFileName));
+            delete m_dic;
+            m_dic = dic;
+            emit dicChanged(m_dic);
+            displayInfoMsg(_q("Loaded dictionary '%1'").arg(iFileName));
+
+            // Save the location of the dictionary in the preferences
+            QSettings qs(ORGANIZATION, PACKAGE_NAME);
+            qs.setValue(PrefsDialog::kINTF_DIC_PATH, iFileName);
+        }
+        catch (std::exception &e)
+        {
+            displayErrorMsg(e.what());
+        }
+    }
+}
+
+
 QAction * MainWindow::addMenuAction(QMenu *menu, QString iText,
                                     const QKeySequence &iShortcut,
                                     QString iStatusTip, const char *iMember,
@@ -424,6 +465,9 @@ void MainWindow::createMenu()
     menuSettings->setTitle(_q("&Settings"));
     addMenuAction(menuSettings, _q("&Choose dictionary..."), _q("Ctrl+C"),
                   _q("Select a new dictionary"), SLOT(onSettingsChooseDic()));
+    addMenuAction(menuSettings, _q("Create &new dictionary..."), QString(""),
+                  _q("Start the wizard for creating a new dictionary "
+                     "from an existing word list"), SLOT(onSettingsCreateDic()));
     addMenuAction(menuSettings, _q("&Preferences..."), _q("Ctrl+F"),
                   _q("Edit the preferences"), SLOT(onSettingsPreferences()),
                   false, QIcon(":/images/preferences.png"));
@@ -701,42 +745,21 @@ void MainWindow::onSettingsPreferences()
 
 void MainWindow::onSettingsChooseDic()
 {
-    if (m_game)
-    {
-        QString msg = _q("Loading a dictionary will stop the current game.");
-        QMessageBox confirmationBox(QMessageBox::Question, _q("Eliot"), msg,
-                                    QMessageBox::Yes | QMessageBox::No, this);
-        confirmationBox.setInformativeText(_q("Do you want to continue?"));
-        confirmationBox.setDefaultButton(QMessageBox::Yes);
-        confirmationBox.setEscapeButton(QMessageBox::No);
-        int res = confirmationBox.exec();
-        if (res == QMessageBox::No)
-            return;
-    }
-
     QString fileName =
         QFileDialog::getOpenFileName(this, _q("Choose a dictionary"), "", "*.dawg");
-    if (!fileName.isEmpty())
-    {
-        destroyCurrentGame();
+    changeDictionary(fileName);
+}
 
-        try
-        {
-            Dictionary *dic = new Dictionary(qtl(fileName));
-            delete m_dic;
-            m_dic = dic;
-            emit dicChanged(m_dic);
-            displayInfoMsg(_q("Loaded dictionary '%1'").arg(fileName));
 
-            // Save the location of the dictionary in the preferences
-            QSettings qs(ORGANIZATION, PACKAGE_NAME);
-            qs.setValue(PrefsDialog::kINTF_DIC_PATH, fileName);
-        }
-        catch (std::exception &e)
-        {
-            displayErrorMsg(e.what());
-        }
-    }
+void MainWindow::onSettingsCreateDic()
+{
+    DicWizard *wizard = new DicWizard(this);
+    wizard->setWindowTitle(_q("Dictionary creation wizard"));
+    connect(wizard, SIGNAL(infoMsg(QString)),
+            this, SLOT(displayInfoMsg(QString)));
+    connect(wizard, SIGNAL(loadDictionary(QString)),
+            this, SLOT(changeDictionary(QString)));
+    wizard->show();
 }
 
 
